package cn.iocoder.yudao.module.reward.controller.admin.redeem;

import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.module.reward.api.reward.RedeemRewardApi;
import cn.iocoder.yudao.module.reward.api.reward.dto.RedeemRewardReqVO;
import cn.iocoder.yudao.module.reward.api.reward.dto.RedeemRewardRespDTO;
import cn.iocoder.yudao.module.reward.service.redeem.RewardRedeemService;
import cn.iocoder.yudao.module.reward.vo.reward.RewardRedeemPageReqVO;
import cn.iocoder.yudao.module.reward.vo.reward.RewardRedeemPageRespVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import javax.validation.Valid;
import java.util.List;

import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;

@Validated
@RestController
@Api(tags = "管理后台 - 礼品管理")
@RequestMapping("/reward/redeem")
public class RedeemRewardController {

    @Resource
    private RedeemRewardApi redeemRewardApi;

    @Resource
    private RewardRedeemService rewardRedeemService;

    @PostMapping("record/page")
    @ApiOperation("兑换记录列表")
    public CommonResult<PageResult<RewardRedeemPageRespVO>> pageInfo(@Valid @RequestBody RewardRedeemPageReqVO reqVO) {
        return success(rewardRedeemService.pageInfo(reqVO));
    }


    @PostMapping("/single")
    @ApiOperation("兑换礼品")
    @PreAuthorize("@ss.hasPermission('ecw:giftManagement:exchange')")
    public CommonResult<RedeemRewardRespDTO> redeemReward(@Valid @RequestBody RedeemRewardReqVO redeemRewardReqVO) {
        return success(redeemRewardApi.redeemReward(redeemRewardReqVO));
    }

    @PostMapping("/batch")
    @ApiOperation("批量兑换礼品")
    @PreAuthorize("@ss.hasPermission('ecw:giftManagement:exchange')")
    public CommonResult<List<RedeemRewardRespDTO>> redeemRewards(@Valid @RequestBody List<RedeemRewardReqVO> redeemRewardReqVOList) {
        return success(redeemRewardApi.redeemRewards(redeemRewardReqVOList));
    }
}
